/*
 * This file is part of Chalk
 *
 * Copyright (c) 2005 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _KRITA_FILTERS_PREVIEW_H_
#define _KRITA_FILTERS_PREVIEW_H_

#include <tdeparts/plugin.h>

class KisView;

namespace Chalk {
namespace Plugins {
namespace FiltersGallery {
    class ChalkFiltersGallery : public KParts::Plugin
    {
        Q_OBJECT
  
        public:
            ChalkFiltersGallery(TQObject *parent, const char *name, const TQStringList &);
            virtual ~ChalkFiltersGallery();
        public slots:
            void showFiltersGalleryDialog();
        private:
        
            KisView * m_view;
    
    
    };

}
}
}



#endif
